@@ -1,4 +1,4 @@
-from Resources.resource import Resource
+from erp_sync.Resources.resource import Resource
 
 class BillInvoices(Resource):
 
@@ -143,25 +143,29 @@ class BillInvoices(Resource):
 
             payload = super().response()
 
-            if 'resource' in payload.keys():
-                payload = payload.get("resource", [])
+            data = payload
 
             # confirms if a single object was read from the database
             if isinstance(payload, dict):
-                payload = [payload]
-
-            if payload is not None:
-
-                if len(payload) > 0:
-                    for i in range(len(payload)):
-                        if 'total_amount' in payload[i].keys():
-                            payload[i]['amount'] = payload[i].pop('total_amount')
-                        if 'customer_id' in payload[i].keys():
-                            payload[i]['vendor_id'] = payload[i].pop('customer_id')
-
-            else:
-                payload = super().response()
+                if 'resource' in payload.keys():
+                    data = payload.get("resource", [])
+                
+            # confirms if a single object was read from the database
+            if isinstance(data, dict):
+                data = [data]
+            
+            # confirms if data is a list
+            if isinstance(data, list):
+                if len(data) > 0:
+                    for i in range(len(data)):
+                        if 'total_amount' in data[i].keys():
+                            data[i]['amount'] = data[i].pop('total_amount')
+                        if 'customer_id' in data[i].keys():
+                            data[i]['vendor_id'] = data[i].pop('customer_id')
+                        
+            if 'resource' in payload.keys():
+                payload["resource"] = data
 
             super().set_response(payload)
 
-            return self
+            return self
\ No newline at end of file
