@@ -16,7 +16,7 @@ from erp_sync.Resources.invoices import Invoices
 from erp_sync.Resources.users import Users
 from erp_sync.Resources.records import Records
 from erp_sync.Resources.uploads import Uploads
-
+from erp_sync.Resources.banks import Banks
 
 class Client(Resource):
 
@@ -28,6 +28,7 @@ class Client(Resource):
         "Taxes": Taxes(),
         "ChartOfAccounts": ChartOfAccounts(),
         "Currencies": Currencies(),
+        "Banks": Banks(),
         "BankAccounts": BankAccounts(),
         "BankTransactions": BankTransactions(),
         "BankTransfers": BankTransfers(),
