@@ -190,28 +190,28 @@ class Customer(Resource):
                     bp_information.update({
                         "CardCode": payload.get("customer_code", "")
                     })
-                
+
                 if 'GroupCode' in additional_properties.keys():
                     bp_information.update({
                         "GroupCode": additional_properties.get("GroupCode", {})
                     })
-                    
+
                     additional_properties.pop("GroupCode")
-                
+
                 if 'Fax' in additional_properties.keys():
                     bp_information.update({
                         "Fax": additional_properties.get("Fax", {})
                     })
-                    
+
                     additional_properties.pop("Fax")
-                
+
                 if 'phone2' in additional_properties.keys():
                     bp_information.update({
                         "Telephone2": additional_properties.get("phone2", {})
                     })
-                    
+
                     additional_properties.pop("phone2")
-                
+
                 data.update({
                     "BPInformation": bp_information
                 })
@@ -329,6 +329,15 @@ class Customer(Resource):
                 if bool(contacts):
                     data["Contacts"] = [contacts]
 
+            # If client type is ODOO
+            elif super().get_client_type() == super().ODOO:
+                data.update({
+                    "name": f'{payload.get("first_name", "")} {payload.get("last_name", "")}',
+                    "display_name": f'{payload.get("first_name", "")} {payload.get("last_name", "")}',
+                    "email": f'{payload.get("email", "")}',
+                    "active":True
+                })
+
             data.update(additional_properties)
 
             return data
@@ -344,7 +353,6 @@ class Customer(Resource):
             elif 'resource' in payload.keys():
                 data = payload.get("resource", [])
 
-
             # confirms if a single object was read from the database
             if isinstance(data, dict):
                 data = [data]
@@ -360,7 +368,7 @@ class Customer(Resource):
 
                         if 'given_name' in data[i].keys():
                             data[i]['last_name'] = data[i].pop('given_name')
-                        
+
             if 'customers' in payload.keys():
                 payload["customers"] = data
             elif 'resource' in payload.keys():
