@@ -1,5 +1,6 @@
 from erp_sync.Resources.resource import Resource
 
+
 class Items(Resource):
 
     urls = {}
@@ -8,8 +9,8 @@ class Items(Resource):
         super().set_client_id(client_id)
         self._set_urls()
         return self
-    
-    def set_company_id(self,company_id):
+
+    def set_company_id(self, company_id):
         super().set_company_id(company_id)
         self._set_urls()
         return self
@@ -17,55 +18,55 @@ class Items(Resource):
     def _set_urls(self):
 
         self.urls = {
-            "new" : f"/companies/{super().get_company_id()}/items",
-            "edit" : f"/companies/{super().get_company_id()}/items",
-            "read" : f"/companies/{super().get_company_id()}/items",
-            "delete" : f"/companies/{super().get_company_id()}/items",
-            "import" : f"/companies/{super().get_company_id()}/import_items"
+            "new": f"/companies/{super().get_company_id()}/items",
+            "edit": f"/companies/{super().get_company_id()}/items",
+            "read": f"/companies/{super().get_company_id()}/items",
+            "delete": f"/companies/{super().get_company_id()}/items",
+            "import": f"/companies/{super().get_company_id()}/import_items"
         }
 
         super().set_urls(self.urls)
 
         return self
-        
-    def read(self,item_id = None, payload = None, method='GET',endpoint=None):
-        
+
+    def read(self, item_id=None, payload=None, method='GET', endpoint=None):
+
         self._set_urls()
 
         if item_id is not None:
             self.urls["read"] = f'{self.urls["read"]}/{item_id}'
             super().set_urls(self.urls)
-        
+
         return super().read(payload, method, endpoint)
-        
-    def edit(self,ledger_id = None, payload = None, method='PUT',endpoint=None):
-        
+
+    def edit(self, ledger_id=None, payload=None, method='PUT', endpoint=None):
+
         self._set_urls()
 
         self.urls["edit"] = f'{self.urls["edit"]}/{ledger_id}'
-        
+
         super().set_urls(self.urls)
-        
+
         return super().edit(payload, method, endpoint)
-        
-    def delete(self,ledger_id = None, payload = None, method='DELETE',endpoint=None):
-        
+
+    def delete(self, ledger_id=None, payload=None, method='DELETE', endpoint=None):
+
         self._set_urls()
 
         self.urls["delete"] = f'{self.urls["delete"]}/{ledger_id}'
 
         super().set_urls(self.urls)
-        
+
         return super().delete(payload, method, endpoint)
-        
-    def import_data(self,ledger_id = None, payload = None, method='GET',endpoint=None):
-        
+
+    def import_data(self, ledger_id=None, payload=None, method='GET', endpoint=None):
+
         self._set_urls()
 
         if ledger_id is not None:
             self.urls["import"] = f'{self.urls["import"]}/{ledger_id}'
             super().set_urls(self.urls)
-            
+
         return super().import_data(payload, method, endpoint)
 
     def payload(self):
@@ -73,14 +74,13 @@ class Items(Resource):
         data = {}
 
         # If client type is Quickbooks Online
-        if super().get_client_type() ==  super().QBO:
+        if super().get_client_type() == super().QBO:
 
             data = {
-                    "type": "<Enter type either purchase or sales>",
-                    "name": "<Enter a unique name>", 
-                    "value": "<Enter the item value>"
-                }
-
+                "type": "<Enter type either purchase or sales>",
+                "name": "<Enter a unique name>",
+                "value": "<Enter the item value>"
+            }
 
         # If client type is ZOHO
         elif super().get_client_type() == super().ZOHO:
@@ -106,20 +106,20 @@ class Items(Resource):
             }
 
         data.update({
-            "additional_properties":{
-                        "help":"Optional data are passed inside this object, the format should be specific to the ERP. View ERP documentation for more details, below are examples of optional data",
-                    }
+            "additional_properties": {
+                "help": "Optional data are passed inside this object, the format should be specific to the ERP. View ERP documentation for more details, below are examples of optional data",
+            }
         })
 
         return data
 
-    def serialize(self, payload = None, operation = None):
+    def serialize(self, payload=None, operation=None):
 
         data = {}
 
         if operation is None:
             return "Specify the operation: Resource.READ, Resource.NEW or Resource.UPDATE"
-        
+
         if operation == super().NEW or operation == super().UPDATE:
 
             # If client type is Quickbooks Online
@@ -130,10 +130,15 @@ class Items(Resource):
                         "Name": payload.get("name", "")
                     })
 
+                if 'value' in payload.keys():
+                    data.update({
+                        "UnitPrice": payload.get("value", 0)
+                    })
+
                 if payload.get("type", "") == "purchase":
                     data.update({
                         "ExpenseAccountRef": {
-                            "name": "Cost of Goods Sold", 
+                            "name": "Cost of Goods Sold",
                             "value": payload.get("value", 0)
                         }
                     })
@@ -141,7 +146,7 @@ class Items(Resource):
                 elif payload.get("type", "") == "sales":
                     data.update({
                         "IncomeAccountRef": {
-                            "name": "Sales of Product Income", 
+                            "name": "Sales of Product Income",
                             "value": payload.get("value", 0)
                         }
                     })
@@ -186,17 +191,26 @@ class Items(Resource):
 
                 if 'item_code' in payload.keys():
                     items.update({
-                    "TotalCostPool": payload.get("value", "")
+                        "TotalCostPool": payload.get("value", "")
                     })
-                
-                # If items has data 
+
+                # If items has data
                 if bool(items):
                     data["Items"] = [items]
 
+            # If client type is ODOO
+            elif super().get_client_type() == super().ODOO:
+                data = {
+                    "name": payload.get("name", ""),
+                    "display_name": payload.get("name", ""),
+                    "description": payload.get("description", ""),
+                    "price": payload.get("value", 0)
+                }
+
             data.update(payload.get("additional_properties", {}))
 
             return data
-        
+
         elif operation == super().READ:
 
             payload = super().response()
@@ -207,18 +221,18 @@ class Items(Resource):
             if isinstance(payload, dict):
                 if 'resource' in payload.keys():
                     data = payload.get("resource", [])
-                
+
             # confirms if a single object was read from the database
             if isinstance(data, dict):
                 data = [data]
-            
+
             # confirms if data is a list
             if isinstance(data, list):
                 if len(data) > 0:
                     for i in range(len(data)):
                         if 'unit_price' in data[i].keys():
                             data[i]['value'] = data[i].pop('unit_price')
-                        
+
             if isinstance(payload, dict):
                 if 'resource' in payload.keys():
                     payload["resource"] = data
@@ -227,4 +241,4 @@ class Items(Resource):
 
             super().set_response(payload)
 
-            return self
\ No newline at end of file
+            return self
