@@ -345,6 +345,15 @@ class Payments(Resource):
                         "Payments": [payment]
                     })
 
+            # If client type is ODOO
+            elif super().get_client_type() == super().ODOO:
+                data = {
+                    "partner_type": "customer",
+                    "date": payload.get("date", ""),
+                    "amount": payload.get("amount", 0),
+                    "partner_id": payload.get("customer_id", ""),
+                    "payment_reference": payload.get("reference", ""),
+                }
             data.update(additional_properties)
 
             return data
